////////////////////////////////////////////////////////////////////////////////////
/// @file CFace.h
/// @author DGI
/// @date 2005-06-15
/// @version 1.0
///
/// @addtogroup chargeur3ds Chargeur 3DS
/// @{
////////////////////////////////////////////////////////////////////////////////////
#ifndef __CFACE_H__
#define __CFACE_H__


#include "Vecteur.h"

#include "CLectureFichierBinaire.h"
#include "CEcritureFichierBinaire.h"

using namespace std;


namespace chargeur3ds {


   ///////////////////////////////////////////////////////////////////////////
   /// @class CFace
   /// @brief Classe reprsentant une face.
   ///
   /// Contient -3 indices vers les 3 vertex dfinissant cette facette (triangulaire)
   ///             -3 indices vers des coordonnes de texture
   ///             - une normale  la face
   ///             - une normale  chaque vertex
   ///
   /// @author DGI-2990
   /// @date 2005-09-27
   ///////////////////////////////////////////////////////////////////////////
   class CFace
   {
   public:
       /// Construction 
       CFace();
       /// Destruction
       ~CFace() {;}

       /// Surcharge de l'oprateurs < (crire dans un fichier binaire)
       friend CEcritureFichierBinaire& operator< ( CEcritureFichierBinaire& out, const CFace& face);
       /// Surcharge de l'oprateurs > (Lecture dans un fichier binaire)
       friend CLectureFichierBinaire& operator> ( CLectureFichierBinaire& in, CFace& face);

       /// Lecture d'un fichier txt
       void importer ( ifstream& in);

       /// Les indices des trois vertex de la face
       int id[3];
       /// Les normales des trois vertex
       Vecteur3 vnormal[3];

       /// Les indices des trois coordones de texture
       int tid[3];

       /// La normale de la face
       Vecteur3 normal;
   private:

   };


} // Fin de l'espace de nom chargeur3ds


#endif // __CFACE_H__


////////////////////////////////////////////////////////////////////////////////////
/// @}
////////////////////////////////////////////////////////////////////////////////////
