////////////////////////////////////////////////////////////////////////////////////
/// @file CMateriel.cpp
/// @author DGI
/// @date 2005-06-15
/// @version 1.0
///
/// @addtogroup chargeur3ds Chargeur 3DS
/// @{
////////////////////////////////////////////////////////////////////////////////////

#ifdef WIN32
#include <windows.h>
#endif

#include <GL/gl.h>

#include "CMateriel.h"

namespace chargeur3ds {

   CMateriel CMateriel::g_sansMateriel;

   ////////////////////////////////////////////////////////////////////////
   ///
   /// @fn CMateriel::CMateriel()
   ///
   /// Constructeur par dfaut
   ///
   /// @return Aucune
   ///
   ////////////////////////////////////////////////////////////////////////
   CMateriel::CMateriel() : name("No material"),
                            color(1,1,1,1)
   {
   }

   ////////////////////////////////////////////////////////////////////////
   ///
   /// @fn CMateriel::~CMateriel()
   ///
   /// Destructeur
   ///
   /// @return Aucune
   ///
   ////////////////////////////////////////////////////////////////////////
   CMateriel::~CMateriel()
   {
   }

   ////////////////////////////////////////////////////////////////////////
   ///
   /// @fn CMateriel::Load(const char* relatif)
   ///
   /// Charge la texture en mmoire opengl
   ///
   /// @return Aucune
   ///
   ////////////////////////////////////////////////////////////////////////
   void CMateriel::Load(const char* relatif)
   {
       map.Load(relatif);
   }

   ////////////////////////////////////////////////////////////////////////
   ///
   /// @fn CMateriel::Remove()
   ///
   /// Libre la texture
   ///
   /// @return Aucune
   ///
   ////////////////////////////////////////////////////////////////////////
   void CMateriel::Remove()
   {
       map.Remove();
   }

   ////////////////////////////////////////////////////////////////////////
   ///
   /// @fn CMateriel::Activate() const
   ///
   /// Active le matriel en vrifiant que le fichier est valide
   ///
   /// @return Aucune
   ///
   ////////////////////////////////////////////////////////////////////////
   void CMateriel::Activate() const
   {
       if ( map.tname.size() > 3)     {//on regarde si le nom du fichier est valide (contient plus que 3 caracteres!!)
           glEnable ( GL_TEXTURE_2D);
           glBindTexture ( GL_TEXTURE_2D,map.textureid);
#if 0
           GLfloat mat_diffuse[] = { color[0], color[1], color[2], color[3] };
           GLfloat mat_specular[] = { 1.0, 1.0, 1.0, 1.0 };
           GLfloat mat_shininess[] = { 50.0 };

           glMaterialfv(GL_FRONT, GL_DIFFUSE, mat_diffuse);
           glMaterialfv(GL_FRONT, GL_SPECULAR, mat_specular);
           glMaterialfv(GL_FRONT, GL_SHININESS, mat_shininess);
#endif
           glColor4f ( 1.0f , 1.0f , 1.0f , 1.0f );

       } else {
           glDisable ( GL_TEXTURE_2D);
#if 0
           GLfloat mat_diffuse[] = { color[0], color[1], color[2], color[3] };
           GLfloat mat_specular[] = { 1.0, 1.0, 1.0, 1.0 };
           GLfloat mat_shininess[] = { 50.0 };

           glMaterialfv(GL_FRONT, GL_DIFFUSE, mat_diffuse);
           glMaterialfv(GL_FRONT, GL_SPECULAR, mat_specular);
           glMaterialfv(GL_FRONT, GL_SHININESS, mat_shininess);
#endif
           glColor4f ( color[0], color[1], color[2], color[3]);
       }
   }

   ////////////////////////////////////////////////////////////////////////
   ///
   /// @fn CMateriel::ImportMaterial ( ifstream& in)
   ///
   /// Lit les paramtres du matriel  partir d'un fichier
   ///
   /// @param[in] in :  Flux de lecture
   ///
   /// @return Aucune
   ///
   ////////////////////////////////////////////////////////////////////////
   void CMateriel::ImportMaterial ( ifstream& in) 
   {
       string r;

       in>>r;        //nom du matriel
       char buff[256];
       in.ignore ( 1);
       in.getline ( buff,256);
       name = string ( buff);

       in>>r;        //col
       in>>color;

       in>>r;        //map

       int n_map;
       in>>n_map;
       for ( int i = 0; i < n_map; i++) {
           map.ImportFname ( in);
       }
   }

   ////////////////////////////////////////////////////////////////////////
   ///
   /// @fn operator< ( CEcritureFichierBinaire& out, const CMateriel& m)
   ///
   /// Surcharge de l'oprateur <
   ///
   /// @param[out] out : Flux d'criture
   /// @param[in] m    : Matriel  crire
   ///
   /// @return Flux d'criture
   ///
   ////////////////////////////////////////////////////////////////////////
   CEcritureFichierBinaire& operator< ( CEcritureFichierBinaire& out, const CMateriel& m)
   {
       out<m.map;
       out<m.name;
       out<m.color;

       return out;
   }

   ////////////////////////////////////////////////////////////////////////
   ///
   /// @fn operator> ( CLectureFichierBinaire& in, CMateriel& m)
   ///
   /// Surcharge de l'oprateur >
   ///
   /// @param[in] in : Flux de lecture
   /// @param[out] m  : Matriel  lire
   ///
   /// @return Flux de lecture
   ///
   ////////////////////////////////////////////////////////////////////////
   CLectureFichierBinaire& operator> ( CLectureFichierBinaire& in, CMateriel& m)
   {
       in>m.map;
       in>m.name;
       in>m.color;

       return in;
   }

}  // Fin de l'espace de nom chargeur3ds


////////////////////////////////////////////////////////////////////////////////////
/// @}
////////////////////////////////////////////////////////////////////////////////////
