////////////////////////////////////////////////////////////////////////////////////
/// @file CModelTexture.h
/// @author DGI
/// @date 2005-06-15
/// @version 1.0
///
/// @addtogroup chargeur3ds Chargeur 3DS
/// @{
////////////////////////////////////////////////////////////////////////////////////
#ifndef __CMODELTEXTURE_H__
#define __CMODELTEXTURE_H__


#include <string>
#include "CLectureFichierBinaire.h"
#include "CEcritureFichierBinaire.h"
#include "Vecteur.h"

using namespace std;


namespace chargeur3ds {

   ///////////////////////////////////////////////////////////////////////////
   /// @class CModelTexture
   /// @brief 
   ///
   ///     Contient les paramtres relatifs  une texture:
   ///  nom de la texture
   ///  index opengl
   ///  type de d'enveloppement  (GL_REPEAT / GL_CLAMP_TO_EDGE ...)
   ///
   /// @author DGI-2990
   /// @date 2005-09-27
   ///////////////////////////////////////////////////////////////////////////
   class CModelTexture
   {
   public:
       /// Type d'enveloppement 
       static int WrapType;

       /// Nom de la texture
       string tname;

       /// Index opengl
       unsigned int textureid;

       /// Permet de mettre  jour le mode d'enveloppement 
       static void SetWrapType ( int wt);

       /// Surcharge de l'oprateurs < (crire dans un fichier binaire)
       friend CEcritureFichierBinaire& operator< ( CEcritureFichierBinaire& out, const CModelTexture& smt);
       /// Surcharge de l'oprateurs > (Lecture dans un fichier binaire)
       friend CLectureFichierBinaire& operator> ( CLectureFichierBinaire& in, CModelTexture& smt);

       /// Constructeur par nom
       CModelTexture ( const string& _tname= string());

       /// Importe les paramtres  partir d'un fichier
       void ImportFname ( ifstream& in);

       /// Charge la texture en memoire Opengl
       void Load(const char* relatif = ".");

       /// Enlve la texture
       void Remove();
   };


} // Fin de l'espace de nom chargeur3ds


#endif // __CMODELTEXTURE_H__


////////////////////////////////////////////////////////////////////////////////////
/// @}
////////////////////////////////////////////////////////////////////////////////////
