////////////////////////////////////////////////////////////////////////////////////
/// @file CObjet.h
/// @author DGI
/// @date 2005-06-15
/// @version 1.0
///
/// @addtogroup chargeur3ds Chargeur 3DS
/// @{
////////////////////////////////////////////////////////////////////////////////////
#ifndef __COBJET_H__
#define __COBJET_H__


#include "CVertex.h"
#include "CFace.h"
#include "CCoordonnee.h"
#include "CMateriel.h"

#include <vector>

using namespace std;


namespace chargeur3ds {


   ///////////////////////////////////////////////////////////////////////////
   /// @class CObjet
   /// @brief 
   ///
   /// Contient un objet compos de :
   ///            un vecteur de sommets
   ///            un vecteur de coordonnes de texture
   ///            un vecteur de faces
   ///            un pivot
   ///            un indice et un pointeur vers un matriel
   ///
   ///    Il est  noter qu'un objet n'a qu'un seul matriel.
   ///
   /// @author DGI-2990
   /// @date 2005-09-27
   ///////////////////////////////////////////////////////////////////////////
   class CObjet
   {
   public:
       ///Construction / destruction
       //---------------------------
       CObjet();
       ~CObjet();

       ///Surcharge des oprateurs d'entre/sortie binaire
       //-------------------------
       /// Oprateur d'criture de fichier binaire
       friend CEcritureFichierBinaire& operator< ( CEcritureFichierBinaire& out, const CObjet& sobj);
       /// Oprateur de lecture de fichier binaire
       friend CLectureFichierBinaire& operator> ( CLectureFichierBinaire& in, CObjet& sobj);

       /// Effectue une mise  l'chelle
       void        mettreAEchelle ( float f);

       /// Effectue une translation
       void        Translate ( Vecteur3 delta);

       /// Effectue une rotation
       void        tourner( float angle, const Vecteur3& axe );

       /// Dessine l'objet
       void        dessiner() const;

       /// Importe l'objet  partir d'un fichier
       void        importer ( ifstream& in);

       /// Calcule la sphre englobante
       double      calculerSphereEnglobante() const;

       /// Calcule le cylindre englobant
       void        calculerCylindreEnglobant(double& rayon, double& bas, double& haut) const;

       /// Calcule le rayon du cylindre englobant
       void        calculerBoiteEnglobante(Vecteur3& coinMin, Vecteur3& coinMax) const;

       /// Calcule le centre de masse de l'objet
       Vecteur3    lireMassCenter() const;

       /// Indice du matriel
       int mat_id;

       /// Pointeur vers le matriel
       CMateriel* ptrMateriel;

       /// Nom de l'objet
       string name;

       /// vecteur de sommets
       vector<CVertex>     vvert;

       /// vecteur de coordonnes de texture
       vector<CCoordonnee> vtc;

       /// vecteur de faces
       vector<CFace>       vface;

       /// Position du pivot
       Vecteur3 positionPivot;
   };


} // Fin de l'espace de nom chargeur3ds


#endif // __COBJET_H__


////////////////////////////////////////////////////////////////////////////////////
/// @}
////////////////////////////////////////////////////////////////////////////////////
