#ifdef _WIN32
#include <windows.h>
#endif
#include <GL/gl.h>
#include <GL/glu.h>
#include <GL/glut.h>
#include <math.h>
#include <iostream>

// Les modeles 3D
#include "CFace.h"
#include "CModel.h"

using namespace std;

// Variables pour l'orientation de la scene.
float          g_Yaw    = 0.0f;
float          g_Pitch  = 0.0f;
float          g_Zoom   = 300.0f;

chargeur3ds::CModel g_leModele;

unsigned int   g_listid_;

// Variables pour gerer le deplacement de la souris.
int            g_MouseX, g_MouseY, g_Button;

// Conserve la profondeur d'un point selectionne.
float          g_PointZ;

enum           Mode { MODE_VIEW, MODE_POINT }    g_Mode = MODE_VIEW;

void Display()
{
    // Efface le tampon image.
    glClear( GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT );

    // Place l'observateur.
    glLoadIdentity();
    float x    = g_Zoom * cos( g_Pitch ) * sin( g_Yaw );
    float y    = g_Zoom * sin( g_Pitch );
    float z    = g_Zoom * cos( g_Pitch ) * cos( g_Yaw );
    gluLookAt( x, y, z, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0 );

    // Dessine les axes.
    glBegin( GL_LINES );
    glColor3f( 1.0f, 0.0f, 0.0f );
    glVertex3f( 0.0f, 0.0f, 0.0f );
    glVertex3f( 1.0f, 0.0f, 0.0f );

    glColor3f( 0.0f, 1.0f, 0.0f );
    glVertex3f( 0.0f, 0.0f, 0.0f );
    glVertex3f( 0.0f, 1.0f, 0.0f );

    glColor3f( 0.0f, 0.0f, 1.0f );
    glVertex3f( 0.0f, 0.0f, 0.0f );
    glVertex3f( 0.0f, 0.0f, 1.0f );
    glEnd();

    // Dessine la courbe.
    //glColor3f( 0.0f, 0.0f, 0.0f );
    //g_Courbe.Draw();
    glDisable(GL_LIGHTING);
    glEnable(GL_TEXTURE_2D);
    glCallList(g_listid_);
    //glDisable(GL_TEXTURE_2D);

    // Affiche le tampon image.
    glutSwapBuffers();
}


void Reshape( int width, int height )
{
    // Ajuste la matrice de projection.
    glMatrixMode( GL_PROJECTION );
    glLoadIdentity();
    gluPerspective( 60.0, (double)width / height, 10, 1000.0 );
    glMatrixMode( GL_MODELVIEW );
}

void    OnMouseButton( int Button, int State, int x, int y )
{
    g_MouseX = x;
    g_MouseY = y;
    g_Button = Button;
}


void OnMouseMove( int x, int y )
{
    float DiffX = g_MouseX - x;
    float DiffY = g_MouseY - y;

    switch( g_Mode )
    {
    case MODE_VIEW:
        {
            // Bouton de gauche en mode vue...
            if( g_Button == GLUT_LEFT_BUTTON )
            {
                // ...on change l'orientation.
                g_Pitch    += DiffY * 0.01f;
                g_Yaw    += DiffX * 0.01f;

                // On affiche la scene.
                glutPostRedisplay();
            }
            // Bouton de droite en mode vue...
            else if( g_Button == GLUT_RIGHT_BUTTON )
            {
                // ...on change la distance a l'origine.
                float    k;
                if( DiffX + DiffY > 0 )
                    k = sqrt( DiffX * DiffX + DiffY * DiffY );
                else
                    k = -sqrt( DiffX * DiffX + DiffY * DiffY );

                if( g_Zoom * ( 1 + k * 0.01 ) > 0.0 )
                    g_Zoom    *= 1 + k * 0.01;

                // On affiche la scene.
                glutPostRedisplay();
            }
        }
        break;        
    }

    g_MouseX = x;
    g_MouseY = y;
}


void OnKeyPressed( unsigned char Key, int x, int y )
{
    switch( Key )
    {
    case 27:
        // ESC.
        exit( 0 );
    }
}


void Init()
{
    // Initialisation des etats d'OpenGL.
    glClearColor( 1.0f, 1.0f, 1.0f, 0.0f );
    glClearDepth( 1.0f );
    glEnable( GL_DEPTH_TEST );
    glDepthFunc( GL_LEQUAL );

    /* La scne  1 */
    g_leModele.Load ( "plante","plante");
    g_leModele.chargerMateriaux();
    g_listid_ = glGenLists (1);
    glNewList ( g_listid_, GL_COMPILE);
    glColor3f(1,1,1);
    g_leModele.dessiner();
    glEndList();
}



int main( int argc, char** argv )
{
    glutInit( &argc, argv );
    glutInitWindowSize( 600, 600 );
    glutInitDisplayMode( GLUT_RGBA | GLUT_DOUBLE | GLUT_DEPTH );
    glutCreateWindow( "Chargeur3DS" );
    Init();
    glutDisplayFunc( Display );
    glutKeyboardFunc( OnKeyPressed );
    //glutSpecialFunc( OnSpecialKeyPressed );
    glutMouseFunc( OnMouseButton );
    glutMotionFunc( OnMouseMove );
    glutReshapeFunc( Reshape );
    glutPostRedisplay();
    glutMainLoop();

    return    0;
}
